pub struct Stats { /* private fields */ }Expand description
Intermediate to bundle MPD statistic functions.
Implementations
Sourceimpl Stats
impl Stats
Sourcepub fn artists(&self) -> Option<u32>
pub fn artists(&self) -> Option<u32>
Returns the amount of artists in the database.
None can either mean there are none or the number unknown.
Sourcepub fn albums(&self) -> Option<u32>
pub fn albums(&self) -> Option<u32>
Returns the amount of albums in the database.
None can either mean there are none or the number unknown.
Sourcepub fn songs(&self) -> Option<u32>
pub fn songs(&self) -> Option<u32>
Returns the amount of songs in the database.
None can either mean there are none or the number unknown.
Sourcepub fn uptime(&self) -> Option<u64>
pub fn uptime(&self) -> Option<u64>
Returns the uptime of the MPD.
None can either mean there are none or the number unknown.
Sourcepub fn db_update_time(&self) -> Option<u64>
pub fn db_update_time(&self) -> Option<u64>
Returns the UNIX_TIMESTAMP of the last database update.
None can either mean there are none or the number unknown.
Sourcepub fn play_time(&self) -> Option<u64>
pub fn play_time(&self) -> Option<u64>
Returns the total playtime since the MPD was started.
None can either mean there are none or the number unknown.
Sourcepub fn db_play_time(&self) -> Option<u64>
pub fn db_play_time(&self) -> Option<u64>
Returns the total duration of all songs in the database.
None can either mean there are none or the number unknown.